@@ -12,6 +12,7 @@ from accqsure.text import Text
 from accqsure.document_types import DocumentTypes
 from accqsure.documents import Documents
 from accqsure.manifests import Manifests
+from accqsure.inspections import Inspections
 
 from accqsure.exceptions import (
     ApiError,
@@ -46,6 +47,7 @@ class AccQsure(object):
         self.document_types = DocumentTypes(self)
         self.documents = Documents(self)
         self.manifests = Manifests(self)
+        self.inspections = Inspections(self)
 
     @property
     def __version__(self) -> str:
@@ -115,8 +117,11 @@ class AccQsure(object):
                         raise ApiError(
                             resp.status, {"message": what.decode("utf8")}
                         )
-                results = await resp.json()
-                return results
+                content_type = resp.headers.get("Content-Type", "").lower()
+                if "application/json" in content_type:
+                    return await resp.json()
+                else:
+                    return await resp.read()
 
     async def _query_stream(
         self, path, method, params=None, data=None, headers=None
