@@ -66,43 +66,6 @@ def list(config, document_type_id):
         )
 
 
-@document.command()
-@click.argument(
-    "file",
-    type=click.Path(
-        exists=True, file_okay=True, dir_okay=False, resolve_path=True
-    ),
-)
-@pass_config
-def convert(config, file):
-    """
-    Convert a file to markdown
-
-    """
-
-    mime = magic.Magic(mime=True)
-    mime_type = mime.from_file(file)
-
-    if mime_type not in DOCUMENT_TYPES:
-        raise ValueError(
-            f"Invalid file type. Detected MIME type '{mime_type}' not in allowed types: {', '.join(DOCUMENT_TYPES.values())}"
-        )
-
-    file_type = DOCUMENT_TYPES[mime_type]
-
-    with open(os.path.expanduser(file), "rb") as f:
-        value = f.read()
-        base64_contents = base64.b64encode(value).decode("utf-8")
-
-    title = os.path.splitext(os.path.basename(file))[0]
-    result = config.accqsure.run(
-        config.accqsure.client.documents.markdown_convert(
-            title, file_type, base64_contents
-        )
-    )
-    click.echo(result)
-
-
 @document.command()
 @click.option("--document-type", "-t", type=click.STRING, required=True)
 @click.option(
